/*
 obj_array.pov
 
 A test file for viewing points saved from circle_place.exe.
 
 Uses the range of circles sizes from cp_pts.inc to pick from an array of objects.
 
 Recommended command line options:
  +w800 +h600 +a0.3 +am2 +r3
 
 I also recommend saving a .png from cp_pigment.pov, and then rendering this file.
 
*/

// include the point set
#include "cp_pts.inc"

// an array of objects, can be any size
// the first entries will correspond to the smaller circle sizes
#declare objects =
array[7]{
 
 // some lousy "grass" objects -- try changing "*1" to "*2" to join the patches
 sphere{0,1 scale<1,.1,1>*1 pigment{rgb<1,1,0>}}
 sphere{0,1 scale<1,.1,1>*1 pigment{rgb<.5,1,0>}}
 sphere{0,1 scale<1,.1,1>*1 pigment{rgb y*.8}}
 
 //  "trees"
 union{
  cylinder{0,y*1.5,.25 pigment{rgb<.5,.3,.1>}}
  sphere{y*1.5,1 pigment{rgb y/2}}
  scale<1,.75,1>
 }
 union{
  cylinder{0,y*1.5,.25 pigment{rgb<.5,.3,.1>}}
  sphere{y*1.5,1 pigment{rgb<.02,.5,.02>}}
  scale<1,1.5,1>
 }
 
 // "pine trees"
 union{
  cone{0,.25,y*4,0 pigment{rgb<.5,.3,.1>}}
  cone{y*.5,1,y*4,0
   pigment{rgb y/3}
  }
 }
 union{
  cone{0,.25,y*4,0 pigment{rgb<.5,.3,.1>}}
  cone{y*.5,1,y*4,0
   pigment{rgb<.02,.3,.02>}
  }
  scale<1,1.5,1>
 }
 
}

union{
 // main object loop
 #declare V=0;
 #while(V<dimension_size(cp_pts,1))
  
  // method for accessing object array using min/max circle sizes from cp_pts.inc
  #declare v1 = cp_size_2-cp_size_1;
  #declare v2 = 1/v1*(cp_pts[V].z-cp_size_1);
  #declare access = ceil(v2*(dimension_size(objects,1)-1));
  
  // failsafe -- just in case
  #if(access>dimension_size(objects,1)-1) #declare access = dimension_size(objects,1)-1; #end
  #if(access<0) #declare access = 0; #end
  
  // an object is chosen from the array
  object{
   objects[access]
   
   // scale it according to this point's radius
   scale <1,1,1>*cp_pts[V].z
   
   // translate it
   translate <cp_pts[V].x,0,cp_pts[V].y>
  }
  
  #declare V=V+1;
 #end
 
 // center, scale
 translate-(x+z)/2
 scale 20
}

plane{y,-.00001 pigment{rgb<.3,.2,.1>}}

camera{
 ultra_wide_angle
 location <0,15,-8>
 look_at -y*5.5
 angle 40*2
}

light_source{<.75,1,-.3>*100000,1.5}